@@ -13,16 +13,14 @@ public:
   Search(const QString& path, QObject *parent = 0);
   ~Search();
 
-  Q_INVOKABLE QVariantList search(const QString& query);
+  Q_INVOKABLE QVariantList search(const QString& query, bool matchWholeWords);
 
-signals:
-  void errorOpen();
-  void error();
+  Q_INVOKABLE bool enable();
 
-private:
-  bool enable();
+public slots:
   void disable();
 
+private:
   SearchPrivate *d_ptr;
 };
 
